use anyhow::Result;
use matrix_sdk::deserialized_responses::SyncResponse;

use crate::app::{events::EventStatus, App};

pub async fn handle(app: &mut App<'_>, sync: &SyncResponse) -> Result<EventStatus> {
    for (m_room_id, m_room) in sync.rooms.join.iter() {
        let room = match app.status.get_room_mut(m_room_id) {
            Some(r) => r,
            None => continue,
        };
        for m_event in m_room.timeline.events.clone() {
            let event = m_event
                .event
                .deserialize()
                .unwrap()
                .into_full_event(m_room_id.clone());
            room.timeline_add(event);
        }
    }

    Ok(EventStatus::Ok)
}
