use crate::app::events::Event;
use anyhow::{bail, Result};
use tokio::{sync::mpsc, time::Duration};
use tokio_util::sync::CancellationToken;

pub async fn poll(channel: mpsc::Sender<Event>, kill: CancellationToken) -> Result<()> {
    async fn stage_2(channel: mpsc::Sender<Event>) -> Result<()> {
        loop {
            if crossterm::event::poll(Duration::from_millis(100))? {
                let event = Event::InputEvent(crossterm::event::read()?);
                channel.send(event).await?;
            } else {
                tokio::task::yield_now().await;
            }
        }
    }
    tokio::select! {
        output = stage_2(channel) => output,
        _ = kill.cancelled() => bail!("received kill signal")
    }
}
