use tui::{
    layout::Alignment,
    style::{Color, Style},
    text::Text,
    widgets::{Block, Borders, Paragraph},
};

use crate::{app::status::StatusMessage, ui::central::InputPosition};

pub fn init<'a>(status_events: &Vec<StatusMessage>, colors: &Vec<Color>) -> Paragraph<'a> {
    let mut command_monitor = Text::default();

    status_events.iter().for_each(|event| {
        // TODO(@Soispha): The added text (`event.content()`) doesn't wrap nicely,
        // it would be nice if it did.
        command_monitor.extend(Text::styled(
            event.content(),
            Style::default().fg(if event.is_error() {
                Color::Red
            } else {
                Color::Cyan
            }),
        ));
    });

    Paragraph::new(command_monitor)
        .block(
            Block::default()
                .title("Command Montior")
                .borders(Borders::ALL)
                .style(Style::default().fg(colors[InputPosition::CommandMonitor as usize])),
        )
        .alignment(Alignment::Center)
}
