use tui::{
    layout::Alignment,
    style::{Color, Style},
    text::Text,
    widgets::{Block, Borders, Paragraph},
};

use crate::{app::status::Room, ui::central::InputPosition};

pub fn init<'a>(room: Option<&'a Room>, colors: &Vec<Color>) -> Paragraph<'a> {
    let mut room_info_content = Text::default();
    if let Some(room) = room {
        room_info_content.extend(Text::styled(room.name(), Style::default().fg(Color::Cyan)));
        if room.encrypted() {
            room_info_content.extend(Text::styled("Encrypted", Style::default().fg(Color::Green)));
        } else {
            room_info_content.extend(Text::styled(
                "Not Encrypted!",
                Style::default().fg(Color::Red),
            ));
        }
    } else {
        room_info_content.extend(Text::styled(
            "No room selected!",
            Style::default().fg(Color::Red),
        ));
    }

    Paragraph::new(room_info_content)
        .block(
            Block::default()
                .title("Room Info")
                .borders(Borders::ALL)
                .style(Style::default().fg(colors[InputPosition::RoomInfo as usize])),
        )
        .alignment(Alignment::Center)
}
