use tui::{
    style::{Color, Modifier, Style},
    text::Span,
    widgets::{Block, Borders, List, ListItem},
};

use crate::{app::status::Status, ui::central::InputPosition};

pub fn init<'a>(status: &'a Status, colors: &Vec<Color>) -> List<'a> {
    let rooms_content: Vec<_> = status
        .rooms()
        .iter()
        .map(|(_, room)| ListItem::new(Span::styled(room.name(), Style::default())))
        .collect();
    List::new(rooms_content)
        .block(
            Block::default()
                .title("Rooms (navigate: arrow keys)")
                .borders(Borders::ALL)
                .style(Style::default().fg(colors[InputPosition::Rooms as usize])),
        )
        .style(Style::default().fg(Color::DarkGray))
        .highlight_style(
            Style::default()
                .fg(Color::Cyan)
                .add_modifier(Modifier::BOLD),
        )
        .highlight_symbol(">")
}
