use tui::{
    layout::Alignment,
    style::{Color, Modifier, Style},
    text::Text,
    widgets::{Block, Borders, Paragraph},
};

use crate::{app::status::Status, ui::central::InputPosition};

pub fn init<'a>(status: &'a Status, colors: &Vec<Color>) -> Paragraph<'a> {
    let mut status_content = Text::styled(
        status.account_name(),
        Style::default().add_modifier(Modifier::BOLD),
    );
    status_content.extend(Text::styled(status.account_user_id(), Style::default()));
    status_content.extend(Text::styled(
        "settings",
        Style::default()
            .fg(Color::LightMagenta)
            .add_modifier(Modifier::ITALIC | Modifier::UNDERLINED),
    ));
    Paragraph::new(status_content)
        .block(
            Block::default()
                .title("Status")
                .borders(Borders::ALL)
                .style(Style::default().fg(colors[InputPosition::Status as usize])),
        )
        .alignment(Alignment::Left)
}
