pub mod central;
pub mod setup;

use std::{io, io::Stdout};

use anyhow::{Context, Result};
use cli_log::info;
use crossterm::{
    event::EnableMouseCapture,
    execute,
    terminal::{enable_raw_mode, EnterAlternateScreen},
};
use tui::{
    style::{Color, Modifier, Style},
    widgets::{Block, Borders},
};
use tui_textarea::TextArea;

fn terminal_prepare() -> Result<Stdout> {
    enable_raw_mode().context("Failed to enable raw mode")?;
    let mut stdout = io::stdout();
    execute!(stdout, EnterAlternateScreen, EnableMouseCapture)?;
    info!("Prepared terminal");
    Ok(stdout)
}

pub fn textarea_activate(textarea: &mut TextArea) {
    textarea.set_cursor_line_style(Style::default().add_modifier(Modifier::UNDERLINED));
    textarea.set_cursor_style(Style::default().add_modifier(Modifier::REVERSED));
    let b = textarea
        .block()
        .cloned()
        .unwrap_or_else(|| Block::default().borders(Borders::ALL));
    textarea.set_block(b.style(Style::default()));
}

pub fn textarea_inactivate(textarea: &mut TextArea) {
    textarea.set_cursor_line_style(Style::default());
    textarea.set_cursor_style(Style::default());
    let b = textarea
        .block()
        .cloned()
        .unwrap_or_else(|| Block::default().borders(Borders::ALL));
    textarea.set_block(b.style(Style::default().fg(Color::DarkGray)));
}
